OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está disponible. Obtenga más información sobre cómo actualizar.",
    "Updater" : "Actualizador",
    "For security reasons the built-in ownCloud updater is using additional credentials. To visit the updater page please click the following button." : "Por razones de seguridad el actualizador incluido en ownCloud está utilizando credenciales adicionales. Para visitar la pagina del actualizador, por favor presione el siguiente botón.",
    "Open updater" : "Abrir el actualizador",
    "A new version is available: %s" : "Hay una nueva versión disponible: %s",
    "Checked on %s" : "Revisado el %s",
    "Updated channel" : "Canal actualizado"
},
"nplurals=2; plural=(n != 1);");
